#
# spec file for package updatecli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           updatecli
Version:        0.86.1
Release:        1.1
Summary:        A Declarative Dependency Management tool
License:        Apache-2.0
URL:            https://github.com/updatecli/updatecli
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.23.1
BuildRequires:  zsh

%description
Updatecli is a tool used to apply file update strategies. Designed to be used
from everywhere, each application "run" detects if a value needs to be updated
using a custom strategy then apply changes according to the strategy.

You describe your update strategy in a file then you run updatecli to it.

Updatecli reads a yaml or a go template configuration file, then works into
three stages.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
GO_VERSION="$(go version)"
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X \"github.com/updatecli/updatecli/pkg/core/version.GoVersion=${GO_VERSION}\" \
   -X github.com/updatecli/updatecli/pkg/core/version.Version=v%{version} \
   -X github.com/updatecli/updatecli/pkg/core/version.BuildTime=${BUILD_DATE}" \
   -o bin/%{name} ./main.go

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.adoc
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.86.1:
  * fix: source block can be nil (#2977)
  * deps: bump updatecli version to v0.86.0 (#2963)
* Mon Nov  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.86.0:
  * feat: add GitHub action autodiscovery plugin (#1964)
  * deps(go): bump module github.com/goccy/go-yaml (#2956)
  * deps(go): bump module github.com/goccy/go-yaml (#2949)
  * chore(deps): Bump anchore/sbom-action from 0.17.3 to 0.17.6
    (#2941)
  * feat(gitbranch): Add git url param to gitbranch plugin (#2850)
  * fix(gittag): allow to specify the sourcebranch where to create
    the tag (#2926)
  * deps(go): bump module github.com/goccy/go-yaml (#2924)
  * fix(temurin) use OS and architecture to filter responses when
    retrieving versions (#2917)
  * fix(temurin) fail explicitly when specifying condition or
    target of kind 'temurin' (#2916)
  * feat(gittag): Add git url param to gittag plugin (#2848)
  * deps(go): bump module cuelang.org/go (#2902)
  * feat: detect auto-debug in the CI (#2822)
  * deps(updatecli/policies): bump all policies (#2712)
  * feat(scm): add bitbucket cloud scm and action support (#2847)
  * fix: show pipeline as skipped if all target are skipped (#2849)
  * deps(go): bump module github.com/fatih/color (#2875)
  * deps(go): bump module github.com/yuin/goldmark (#2870)
  * deps(go): bump module
    github.com/testcontainers/testcontainers-go (#2861)
  * deps(go): bump module helm.sh/helm/v3 (#2859)
  * fix: disabling temurin s390x test (#2852)
  * feat(core/pipeline): allow dependency across
    source/conditions/targets (#2800)
  * fix(doc): Typos (#2824)
  * chore(deps): Bump anchore/sbom-action from 0.17.2 to 0.17.3
    (#2823)
  * chore: deps(go): bump module github.com/drone/go-scm to v1.38.8
    (#2812)
  * Fix bug when gitea request fails (#2806)
  * deps: bump updatecli version to v0.85.0 (#2794)
* Fri Oct 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.85.0:
  * deps(go): bump module github.com/getsops/sops/v3 (#2787)
  * chore(deps): Bump sigstore/cosign-installer from 3.6.0 to 3.7.0
    (#2771)
  * feat(autodiscovery/precommit): initial implementation (#2773)
  * feat: dockerfile autodiscovery should ignore stage name and
    scratch (#2752)
  * deps(go): bump module golang.org/x/text (#2772)
  * Disable spellcheck (#2765)
  * chore(gha): update check-spelling to 0.0.22 (#2759)
  * deps: Bump Golang version to 1.23.2 (#2753)
  * deps: bump updatecli version to v0.84.1 (#2746)
* Wed Oct  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.84.1:
  * Fix prerelease semver filtering when current version is stable
    (#2736)
  * fix(prow/e2e): ignore broken image and use updatecli-test
    (#2737)
  * deps(go): bump module github.com/fluxcd/source-controller/api
    (#2729)
  * chore: deps(go): bump module github.com/drone/go-scm to v1.38.7
    (#2724)
  * deps(go): bump module helm.sh/helm/v3 (#2719)
  * deps(go): bump module helm.sh/helm/v3 (#2713)
  * chore: deps(go): bump module github.com/drone/go-scm to v1.38.6
    (#2706)
  * deps(go): bump module github.com/beevik/etree (#2702)
  * deps(go): bump module github.com/aws/aws-sdk-go (#2691)
  * chore: update golang patch one at a time (#2689)
  * deps(go): bump module github.com/getsops/sops/v3 (#2684)
  * deps: Bump Golang version to 1.23.1 (#2672)
  * deps(go): bump module
    github.com/testcontainers/testcontainers-go (#2677)
  * deps: bump docker dependencies (#2671)
  * deps(go): bump module golang.org/x/mod (#2669)
  * deps(go): bump module golang.org/x/text (#2664)
  * deps(go): bump module golang.org/x/oauth2 (#2658)
  * chore(deps): Bump github.com/opencontainers/runc from 1.1.12 to
    1.1.14 (#2647)
  * chore(text): switch to httpclient (#2622)
  * chore(spelling): add end of line new line (#2632)
  * fix spelling warning (#2629)
  * deps: bump updatecli version to v0.84.0 (#2623)
* Tue Sep 24 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package updatecli: a declarative dependency management tool
